@@ -20,10 +20,11 @@ require 5.004;
 #use Carp qw(carp croak);
 use Pod::Parser;
 use Text::Tabs;
+use locale;
 
 use strict;
 use vars qw(@ISA %ESCAPES $VERSION %LyxCodes $VERSION);
-$VERSION = 0.20;        # current module version.
+$VERSION = 0.25;        # current module version.
 @ISA = qw(Pod::Parser);
 
 ################################################################################
@@ -302,6 +303,7 @@ sub textblock {
    local $_ = shift;
    my $line = shift;
    my @input_lines;
+   my $buffer;
 
    # before we do anything else check for \ and replace it...
    s/\\/\n\\backslash \n/g;
@@ -319,13 +321,29 @@ sub textblock {
          return;
       }
       if ( $$self{MODE} eq "list" ) {  # lists must be handled differantly..
-         $_ = $$self{listdata} . " " . $_;
-         $$self{listdata} = "";
+         # Ok I ran across an issue where the list name had multiple words
+         # in it which would cause the output to not look right. So we need
+         # to account for it.
+         # $_ = $$self{listdata} . " " . $_;
+         # $$self{listdata} = "";
          $_ = $self->interpolate($_, $line);
-         $_ = $self->wrap( $_ );
-         $self->output( $_ );
+         $buffer = $self->wrap( $_ );
+         # now lets handle the case where their may be more than one word in
+         # the list name.
+         $_ = $$self{listdata};
+         if ( /\\/ ) {  # if there are any back slashes that means their is more
+                        # more than one word...
+            $_ = $self->interpolate($_, $line);
+            $self->output( $_ . "\n "); # note the space is important.
+            $self->output($buffer);
+         } else {
+            $_ = $self->interpolate($_, $line);
+            $self->output( $_ . " " . $buffer);
+         }
+
          $$self{paragraph}++;
          $$self{MODE} = "";      # must unset the mode.
+         $$self{listdata} = "";  # must unset the list data.
          return;
       }
 
@@ -363,12 +381,12 @@ sub interior_sequence {
    # first lets deal with the most common cases..
    #### BOLD #########
    if ( $command eq 'B' ) {
-      return ( "\n\\series bold\n" . $_ . " \n\\series default \n");
+      return ( "\n\\series bold \n" . $_ . "\n\\series default \n");
    }
 
    #### ITALICS ############
    if ( $command eq 'I') {
-      return ( "\\shape italic \n" . $_ . " \n\\shape default \n");
+      return ( "\n\\shape italic \n" . $_ . "\n\\shape default \n");
    }
 
    ###### CODE OR TYPEWRITER TEXT ######
@@ -385,7 +403,7 @@ sub interior_sequence {
 
    ##### LINK OR CROSS REFERENCE ##########
    if ( $command eq 'L' ) {
-      return $_;     # for now do nothing. I intend to come back to this
+      return cmd_link($_);     # for now do nothing. I intend to come back to this
                      # once basic functions are working.
    }
 
@@ -422,6 +440,7 @@ sub interior_sequence {
 sub begin_pod {
    my $self = shift;
    my $out_fh = $self->output_handle();
+   my $buffer;
 
    print $out_fh "#pod2lyx created this file on: " . localtime()  . "\n";
    print $out_fh <<HEAR_DOC;
@@ -441,6 +460,10 @@ sub begin_pod {
 \\use_geometry 1
 \\use_amsmath 0
 \\paperorientation portrait
+\\leftmargin 17mm
+\\topmargin 12mm
+\\rightmargin 17mm
+\\bottommargin 12mm
 \\secnumdepth 3
 \\tocdepth 3
 \\paragraph_separation indent
@@ -456,8 +479,21 @@ HEAR_DOC
    # ok the main preamble is done now lets set the title...
    # note lyx_title is set by the class user when they create the class..
    if (defined $$self{lyx_title} ) {
-      print $out_fh "\\layout Title\n\n" . $$self{lyx_title} .
-         "\n\\layout Standard\n";
+      print $out_fh "\\layout Title\n\n" . $$self{lyx_title} . "\n";
+      if ( (defined $$self{footnote}) and !($$self{footnote}) ) {
+         print $out_fh "\\begin_float footnote \n\\layout Standard\n\n";
+         $buffer = "Generated by pod2lyx V" . $VERSION . " from " . $$self{podfile};
+         # Ok I don't know why this is but if the line wrapping mode for foot
+         # notes is differant than every thing else. Basicly if $buffer is
+         # greater than 82 char's long then the document doesn't look right
+         # in LyX also the page break will not be reconized either.
+         my $test = length($buffer);
+         if ( length($buffer) > 83 ) {
+            substr($buffer, 82, 0) = "\n";
+         }
+         print $out_fh $buffer . "\n\\end_float \n";
+      }
+      print $out_fh "\\layout Standard\n";
    }
 
    # insert a page break if the class user asked for it...
@@ -516,6 +552,8 @@ sub output {
 # cmd_head1
 ################################################################################
 # First level heading paragraph...
+# This outputs the heading and generates a label so we can do cross referances
+# later on in the code...
 #
 
 sub cmd_head1 {
@@ -523,6 +561,7 @@ sub cmd_head1 {
    return if $$self{EXCLUDE};
 
    local $_ = shift;
+   my $label = $_;
 
    $$self{MODE} = "head1";
 
@@ -537,6 +576,12 @@ sub cmd_head1 {
             # blank lines in the output stream... We only one one newline
             # so we force it to that...
    $self->output("\\layout Section\n\n" . $_ . "\n");
+
+   $label =~ s/\n//g;
+   $label =~ s/\s/_/g;
+   $label = "\L$label";    # convert the section name to lower case.
+   $self->output("\\begin_inset LatexCommand \\label{sec:" . $label . "}\n\n\\end_inset \n\n\n");
+
 }
 
 ################################################################################
@@ -550,6 +595,7 @@ sub cmd_head2 {
    return if $$self{EXCLUDE};
 
    local $_ = shift;
+   my $label = $_;
 
    $$self{MODE} = "head2";
 
@@ -563,6 +609,11 @@ sub cmd_head2 {
             # we force the issue...
    $self->output("\\layout Subsection\n\n" . $_ . "\n");
 
+   $label =~ s/\n//g;
+   $label =~ s/\s/_/g;
+   $label = "\L$label";    # convert the section name to lower case.
+   $self->output("\\begin_inset LatexCommand \\label{sec:" . $label . "}\n\n\\end_inset \n\n\n");
+
 }
 
 ################################################################################
@@ -622,7 +673,7 @@ sub cmd_back {
 sub cmd_item {
    my $self = shift;
    local $_ = shift;
-   my $command = $_;    # save the command for later referance..
+   my $tempbuff = "";   # temp buffer
 
    s/^item //;          # strip the item section off the command. Notice the
                         # space we want that gone as well.
@@ -653,10 +704,17 @@ sub cmd_item {
       if (!($$self{MODE} eq "list" )) {
          $self->mode_switch("list");
       }
+      # Ok I ran into another bug :( Where a list would not have an assiated
+      # paragraph so we must take care of it here..
+      if ( !( $$self{listdata} eq "") ) {
+         $tempbuff = $self->interpolate( $$self{listdata} , 0);
+         $self->output( $tempbuff . "\n");
+      }
+
       $self->output("\\layout List\n\\labelwidthstring 00.00.0000\n\n");
       # I'm not sure what the labelwidthstring does but it is needed.
       # also if the list head has spaces in it we must escape them...
-      s/\s/\\protected_separator\n/g;
+      s/\s/\n\\protected_separator\n/g;
       $$self{listdata} = $_;
       $$self{paragraph} = 0;
       return;
@@ -827,7 +885,7 @@ sub wrap {
 # to watch out for it. Also what we are doing is replacing spaces which makes
 # this a little more dificult because we end up having to process this thing
 # one char at a time to make it work :( I'm sure a regular expresion guru could
-# make this work but I'm not their yet...
+# make this work better but I'm not their yet...
 
 sub cmd_space {
    local $_ = shift;
@@ -847,6 +905,41 @@ sub cmd_space {
    return($output);
 }
 
+################################################################################
+# cmd_link
+################################################################################
+# This function handles the L<> interer item..
+# Links come in mainly two forms:
+# 1) links to items contained in this document
+# 2) Links to items outside this document.
+#
+# We are going to try to handle both of these cases.
+
+sub cmd_link {
+   local $_ = shift;
+   my $manpage;         # manpage link
+   my $section;         # section ref.
+
+   my $output = '';     # out output formated correctly...
+
+   # if the pod contained some text for use to output use it...
+   if ( /\|/ ) {
+      ($output, $manpage) = split(/\|/, $_, 2);
+      return $output;
+   }
+   # Ok the pod did not provide any link text so lests figure out what we need
+   # to do..
+
+   # leading and trailing whitespace isn't important; get rid of it..
+   #s/^\s+//;
+   #s/\s+$//;
+
+
+
+   return $_;
+}
+
+
 ################################################################################
 # mode_switch
 ################################################################################
